# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.3](https://github.com/agntcy/slim/compare/slim-signal-v0.1.2...slim-signal-v0.1.3) - 2025-07-31

### Other

- remove Agent and AgentType and adopt Name as application identifier ([#477](https://github.com/agntcy/slim/pull/477))

## [0.1.2](https://github.com/agntcy/slim/compare/slim-signal-v0.1.1...slim-signal-v0.1.2) - 2025-04-24

### Other

- declare all dependencies in workspace Cargo.toml ([#187](https://github.com/agntcy/slim/pull/187))
- upgrade to rust edition 2024 and toolchain 1.86.0 ([#164](https://github.com/agntcy/slim/pull/164))

## [0.1.1](https://github.com/agntcy/slim/compare/slim-signal-v0.1.0...slim-signal-v0.1.1) - 2025-04-08

### Other

- update copyright ([#109](https://github.com/agntcy/slim/pull/109))

## [0.1.0](https://github.com/agntcy/slim/releases/tag/slim-signal-v0.1.0) - 2025-02-10

### Added

- Stage the first commit of SLIM (#3)

### Other

- reduce the number of crates to publish (#10)
